OSSP CVS Repository

ossp - Difference in ossp-pkg/rc/rc_test.sh versions 1.15 and 1.16
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/rc/rc_test.sh 1.15 -> 1.16

--- rc_test.sh   2002/07/04 16:51:49     1.15
+++ rc_test.sh   2002/07/05 11:16:20     1.16
@@ -28,26 +28,26 @@
 #  test_rc.sh: Run-command processor test script
 
 # Test short options, should fail for false combination usage
 #echo "./rc -dvef rcfunc/rc.func -hilpsrvxLcqt samba start sleep=2 restart"
 #./rc -dVef rcfunc/rc.func -hilpsrvxLcqt samba start sleep=2 restart
 
 # Test short options, should succeed
 #echo; echo "./rc -derv -L /u/ms/ossp/rc/rcdings/rcfiles/rc.%{RCFILE:s/^all$/*/} -c /u/ms/ossp/rc/rcdings/rc.conf -f /u/ms/ossp/rc/rcfunc/rc.func -t /tmp openssh stop sleep=4 start daily minsize=2097152"
 #./rc -derv -L /u/ms/ossp/rc/rcdings/rcfiles/rc.d/rc.%{RCFILE:s/^all$/*/} -c /u/ms/ossp/rc/rcdings/rc.conf -f /u/ms/ossp/rc/rcfunc/rc.func -t /tmp openssh stop sleep=4 start daily minsize=2097152
 
 # Test some long options, should fail for false combination usage
 echo; echo "./rc --verbose --silent --ParseSectionDef \"%(.+)\" uucp stop sleep=6 start"
 ./rc --verbose --silent --ParseSectionDef "%(.+)" uucp stop sleep=6 start
 echo; echo "./rc --query myvar --silent --ParseSectionDef \"%(.+)\" zebra bing bang"
 ./rc --query myvar --silent --ParseSectionDef "%(.+)" zebra bing bang
-echo; echo "./rc --conf /sfw/rc.conf --ParseSectionDef \"%(.+)\" --locate /u/ms/ossp/rc/rcdings/rcfiles/ --query this barf test"
-./rc --conf /sfw/rc.conf --ParseSectionDef "%(.+)" --locate /u/ms/ossp/rc/rcdings/rcfiles/ --query this barf test
+echo; echo "./rc --conf /usr/opkg/etc/rc.conf --ParseSectionDef \"%(.+)\" --locate ./rc_test/ --query this barf test"
+./rc --conf /usr/opkg/etc/rc.conf --ParseSectionDef "%(.+)" --locate ./rc_test/ --query this barf test
 
 # Test minimal set of long options, should succeed
 echo; echo "./rc --debug --version --ParseSectionDef \"%(.+)\" rsyncd nothing matters but the version"
 ./rc --debug --version --ParseSectionDef "%" rsyncd nothing matters but the version
-echo; echo "./rc --conf /sfw/rc.conf --ParseSectionDef \"%(.+)\" --locate /cw/etc/rc.d:/u/ms/ossp/rc/rcdings/rcfiles:/etc/rc --query all barf test"
-./rc --conf /sfw/rc.conf --ParseSectionDef "%(.+)" --locate /cw/etc/rc.d:/u/ms/ossp/rc/rcdings/rcfiles:/etc/rc --query all barf test
+echo; echo "./rc --conf /usr/opkg/etc/rc.conf --ParseSectionDef \"%(.+)\" --locate /usr/opkg/etc/rc.d:./rc_test:/etc/rc --query all barf test"
+./rc --conf /usr/opkg/etc/rc.conf --ParseSectionDef "%(.+)" --locate /usr/opkg/etc/rc.d:./rc_test:/etc/rc --query all barf test
 
 # FIXME these cases are not handled yet by our configuration FIXME #
 #echo; echo "./rc --debug --version"
@@ -58,46 +58,46 @@
 #./rc --debug --info --verbose
 #echo; echo "./rc --conf /etc/rc.conf --debug --info --raw"
 #./rc --conf /etc/rc.conf --debug --info --raw
 #echo; echo "./rc --conf /sfw/rc.conf --tmp /sfw/RPM/TMP --debug --labels rsyncd"
 #./rc --conf /sfw/rc.conf --tmp /sfw/RPM/TMP --debug --labels rsyncd
 # FIXME these cases are not handled yet by our configuration FIXME #
 
-echo; echo "./rc --func /u/ms/ossp/rc/rcfunc/rc.func --print --ParseSectionDef \"%(.+)\" --verbose openssh stop sleep=4 start"
-./rc --func /u/ms/ossp/rc/rcfunc/rc.func --print --ParseSectionDef "%(.+)" --verbose openssh stop sleep=4 start
-echo; echo "./rc --func /u/ms/ossp/rc/rcfunc/rc.func --info --eval uucp restart"
-./rc --func /u/ms/ossp/rc/rcfunc/rc.func --info --eval uucp restart
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func --tmp /tmp --ParseSectionDef \"%(.+)\" --print uucp start"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func --tmp /tmp --ParseSectionDef "%(.+)" --print uucp start
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func --tmp /tmp --debug --ParseSectionDef \"%(.+)\" --print ntp sync"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func --tmp /tmp --debug --ParseSectionDef "%(.+)" --print ntp sync
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func --tmp /tmp --debug --silent --ParseSectionDef \"%(.+)\" --print ralf feed suppe"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func --tmp /tmp --debug --silent --ParseSectionDef "%(.+)" --print ralf feed suppe
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /u/ms/ossp/rc/rcfiles/ --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --print samba search finish destroy"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /u/ms/ossp/rc/rcfiles/ --ParseSectionDef "%(.+)" --tmp /tmp --silent --print samba search finish destroy
-
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /u/ms/ossp/rc/rcfiles/ --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --print all feed suppe"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /u/ms/ossp/rc/rcfiles/ --ParseSectionDef "%(.+)" --tmp /tmp --silent --print all feed suppe
-
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --print all config barf gag"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --print all config barf gag
-
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --eval all config start"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --eval all config start
-
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --exec all config start"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --exec all config start
-
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --print pam info"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --print pam info
+echo; echo "./rc --func rc_test/rcfuncs --print --ParseSectionDef \"%(.+)\" --verbose openssh stop sleep=4 start"
+./rc --func rc_test/rcfuncs --print --ParseSectionDef "%(.+)" --verbose openssh stop sleep=4 start
+echo; echo "./rc --func ./rc_test/rcfuncs --info --eval uucp restart"
+./rc --func ./rc_test/rcfuncs --info --eval uucp restart
+echo; echo "./rc --conf rc_test/myrc.conf --func ./rc_test/rcfuncs --tmp /tmp --ParseSectionDef \"%(.+)\" --print uucp start"
+./rc --conf rc_test/myrc.conf --func ./rc_test/rcfuncs --tmp /tmp --ParseSectionDef "%(.+)" --print uucp start
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs --tmp /tmp --debug --ParseSectionDef \"%(.+)\" --print ntp sync"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs --tmp /tmp --debug --ParseSectionDef "%(.+)" --print ntp sync
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs --tmp /tmp --debug --silent --ParseSectionDef \"%(.+)\" --print ralf feed suppe"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs --tmp /tmp --debug --silent --ParseSectionDef "%(.+)" --print ralf feed suppe
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L rc_test --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --print samba search finish destroy"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L rc_test --ParseSectionDef "%(.+)" --tmp /tmp --silent --print samba search finish destroy
+
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L ./rc_test --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --print all feed suppe"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L ./rc_test --ParseSectionDef "%(.+)" --tmp /tmp --silent --print all feed suppe
+
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --print all config barf gag"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --print all config barf gag
+
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --eval all config start"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --eval all config start
+
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --exec all config start"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --exec all config start
+
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --print pam info"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --print pam info
 
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --print apache config start"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /sw/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --print apache config start
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef \"%(.+)\" --tmp /tmp --silent --debug --print apache config start"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L /usr/opkg/etc/rc.d --ParseSectionDef "%(.+)" --tmp /tmp --silent --debug --print apache config start
 
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /u/ms/ossp/rc/rcfiles/ --ParseSectionDef \"<(.+)>\" --tmp /tmp --silent --debug --print all config start"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /u/ms/ossp/rc/rcfiles/ --ParseSectionDef "<(.+)>" --tmp /tmp --silent --debug --print all config start
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L ./rc_test/ --ParseSectionDef \"<(.+)>\" --tmp /tmp --silent --debug --print all config start"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L ./rc_test/ --ParseSectionDef "<(.+)>" --tmp /tmp --silent --debug --print all config start
 
-echo; echo "./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /u/ms/ossp/rc/rcfiles/ --ParseSectionDef \"<(.+)>\" --tmp /tmp --silent --debug --print pam info"
-./rc --conf rcdings/myrc.conf --func /u/ms/ossp/rc/rcfunc/rc.func -L /u/ms/ossp/rc/rcfiles/ --ParseSectionDef "<(.+)>" --tmp /tmp --silent --debug --print pam info
+echo; echo "./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L ./rc_test/ --ParseSectionDef \"<(.+)>\" --tmp /tmp --silent --debug --print pam info"
+./rc --conf ./rc_test/myrc.conf --func ./rc_test/rcfuncs -L ./rc_test/ --ParseSectionDef "<(.+)>" --tmp /tmp --silent --debug --print pam info
 
 # Next milestone
 #RequireOwner
@@ -28,26 +28,26 @@
 
 # Test short options, should fail for false combination usage
-#echo "./rc -dvef rcfunc/rc.func -hilpsrvxLcqt samba start sleep=2 restart"
-#./rc -dVef rcfunc/rc.func -hilpsrvxLcqt samba start sleep=2 restart
+#echo "./rc -dvef ./rc_test/rcfuncs -hilpsrvxLcqt samba start sleep=2 restart"
+#./rc -dVef ./rc_test/rcfuncs -hilpsrvxLcqt samba start sleep=2 restart
 
 # Test short options, should succeed
@@ -28,26 +28,26 @@
 
 # Test short options, should succeed
-#echo; echo "./rc -derv -L /u/ms/ossp/rc/rcdings/rcfiles/rc.%{RCFILE:s/^all$/*/} -c /u/ms/ossp/rc/rcdings/rc.conf -f /u/ms/ossp/rc/rcfunc/rc.func -t /tmp openssh stop sleep=4 start daily minsize=2097152"
-#./rc -derv -L /u/ms/ossp/rc/rcdings/rcfiles/rc.d/rc.%{RCFILE:s/^all$/*/} -c /u/ms/ossp/rc/rcdings/rc.conf -f /u/ms/ossp/rc/rcfunc/rc.func -t /tmp openssh stop sleep=4 start daily minsize=2097152
+#echo; echo "./rc -derv -L ./rc_test/rc.%{RCFILE:s/^all$/*/} -c ./rc.conf -f ./rc_test/rcfuncs -t /tmp openssh stop sleep=4 start daily minsize=2097152"
+#./rc -derv -L ./rc_test/rc.d/rc.%{RCFILE:s/^all$/*/} -c ./rc.conf -f ./rc_test/rcfuncs -t /tmp openssh stop sleep=4 start daily minsize=2097152
 
 # Test some long options, should fail for false combination usage
@@ -58,46 +58,46 @@
 #echo; echo "./rc --conf /etc/rc.conf --debug --info --raw"
 #./rc --conf /etc/rc.conf --debug --info --raw
-#echo; echo "./rc --conf /sfw/rc.conf --tmp /sfw/RPM/TMP --debug --labels rsyncd"
-#./rc --conf /sfw/rc.conf --tmp /sfw/RPM/TMP --debug --labels rsyncd
+#echo; echo "./rc --conf /usr/opkg/etc/rc.conf --tmp /tmp --debug --labels rsyncd"
+#./rc --conf /usr/opkg/etc/rc.conf --tmp /tmp --debug --labels rsyncd
 # FIXME these cases are not handled yet by our configuration FIXME #
 

CVSTrac 2.0.1